ytree\.arbor\.io\.CatalogDataFile
=================================

.. currentmodule:: ytree.arbor.io

.. autoclass:: CatalogDataFile

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CatalogDataFile.__init__
   
   

   
   
   